macholib.mach_o — Low-level definitions — macholib v1.4.3 documentation

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »

# `macholib.mach_o` — Low-level definitions

This module defines constants and packable structure types that correspond to elements of a Mach-O file.

The names of classes and constants is the same as those in the Mach-O header files and Apple’s documentation. This document therefore doesn’t explictly document the names in this module.

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »